@@ -15,8 +15,8 @@
  *                                                                         *
  ***************************************************************************/
 #include "knowittray.h"
-#include <kpopupmenu.h>
-#include <klocale.h>
+#include <tdepopupmenu.h>
+#include <tdelocale.h>
   
 KnowitTray::KnowitTray (TQWidget* parent, const char* name) :
    KSystemTray(parent, name)
@@ -25,7 +25,7 @@ KnowitTray::KnowitTray (TQWidget* parent, const char* name) :
       TQT_SLOT(slotUndock()));
 }
 
-void KnowitTray::contextMenuAboutToShow (KPopupMenu* menu)
+void KnowitTray::contextMenuAboutToShow (TDEPopupMenu* menu)
 {
    menu->removeItemAt(menu->count()-1);
    menu->insertItem(i18n("&Quit"), parent(), TQT_SLOT(slotFileQuit()));
